@@ -1,7 +1,7 @@
 package Complete::Bash;
 
-our $DATE = '2016-02-03'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2016-09-27'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -201,7 +201,7 @@ Caveats:
     % cmd --foo = bar
 
 Because they both expand to `['--foo', '=', 'bar']`. But obviously
-`Getopt::Long` does not regard the two as equivalent.
+<pm:Getopt::Long> does not regard the two as equivalent.
 
 _
     args_as => 'array',
@@ -374,7 +374,7 @@ sub join_wordbreak_words {
     while (++$i < @$words) {
         my $w = $words->[$i];
         if ($w =~ /\A[\@=:]+\z/) {
-            if (@$new_words) {
+            if (@$new_words and $#$new_words != $cword) {
                 $new_words->[-1] .= $w;
                 $cword-- if $cword >= $i || $cword >= @$new_words;
             } else {
@@ -551,7 +551,7 @@ Complete::Bash - Completion routines for bash shell
 
 =head1 VERSION
 
-This document describes version 0.27 of Complete::Bash (from Perl distribution Complete-Bash), released on 2016-02-03.
+This document describes version 0.28 of Complete::Bash (from Perl distribution Complete-Bash), released on 2016-09-27.
 
 =head1 DESCRIPTION
 
@@ -672,13 +672,13 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<completion>* => I<hash|array>
+=item * B<$completion>* => I<hash|array>
 
 Completion answer structure.
 
 Either an array or hash. See function description for more details.
 
-=item * B<opts> => I<hash>
+=item * B<$opts> => I<hash>
 
 =back
 
@@ -811,7 +811,7 @@ equivalent:
 =back
 
 Because they both expand to C<['--foo', '=', 'bar']>. But obviously
-C<Getopt::Long> does not regard the two as equivalent.
+L<Getopt::Long> does not regard the two as equivalent.
 
 This function is not exported by default, but exportable.
 
@@ -819,11 +819,11 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<cmdline> => I<str>
+=item * B<$cmdline> => I<str>
 
 Command-line, defaults to COMP_LINE environment.
 
-=item * B<opts> => I<hash>
+=item * B<$opts> => I<hash>
 
 Options.
 
@@ -838,7 +838,7 @@ doing tab completion.
 
 =back
 
-=item * B<point> => I<int>
+=item * B<$point> => I<int>
 
 Point/position to complete in command-line, defaults to COMP_POINT.
 
@@ -877,11 +877,11 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<cmdline> => I<str>
+=item * B<$cmdline> => I<str>
 
 Command-line which contains a marker character.
 
-=item * B<marker> => I<str> (default: "^")
+=item * B<$marker> => I<str> (default: "^")
 
 Marker character.
 
